==> ace_6.5.8.orig.tar.gz: ACE_wrappers/TAO/TAO_IDL/include/ast_interface_fwd.h <==
// This may look like C, but it's really -*- C++ -*-
/*

COPYRIGHT

Copyright 1992, 1993, 1994 Sun Microsystems, Inc.  Printed in the United
States of America.  All Rights Reserved.

This product is protected by copyright and distributed under the following
license restricting its use.

The Interface Definition Language Compiler Front End (CFE) is made
available for your use provided that you include this license and copyright
notice on all media and documentation and the software program in which
this product is incorporated in whole or part. You may copy and extend
functionality (but may not remove functionality) of the Interface
Definition Language CFE without charge, but you are not authorized to
license or distribute it to anyone else except as part of a product or
program developed by you or with the express written consent of Sun
Microsystems, Inc. ("Sun").

The names of Sun Microsystems, Inc. and any of its subsidiaries or
affiliates may not be used in advertising or publicity pertaining to
distribution of Interface Definition Language CFE as permitted herein.

This license is effective until terminated by Sun for failure to comply
with this license.  Upon termination, you shall destroy or return all code
and documentation for the Interface Definition Language CFE.

INTERFACE DEFINITION LANGUAGE CFE IS PROVIDED AS IS WITH NO WARRANTIES OF
ANY KIND INCLUDING THE WARRANTIES OF DESIGN, MERCHANTIBILITY AND FITNESS
FOR A PARTICULAR PURPOSE, NONINFRINGEMENT, OR ARISING FROM A COURSE OF
DEALING, USAGE OR TRADE PRACTICE.

INTERFACE DEFINITION LANGUAGE CFE IS PROVIDED WITH NO SUPPORT AND WITHOUT
ANY OBLIGATION ON THE PART OF Sun OR ANY OF ITS SUBSIDIARIES OR AFFILIATES
TO ASSIST IN ITS USE, CORRECTION, MODIFICATION OR ENHANCEMENT.

SUN OR ANY OF ITS SUBSIDIARIES OR AFFILIATES SHALL HAVE NO LIABILITY WITH
RESPECT TO THE INFRINGEMENT OF COPYRIGHTS, TRADE SECRETS OR ANY PATENTS BY
INTERFACE DEFINITION LANGUAGE CFE OR ANY PART THEREOF.

IN NO EVENT WILL SUN OR ANY OF ITS SUBSIDIARIES OR AFFILIATES BE LIABLE FOR
ANY LOST REVENUE OR PROFITS OR OTHER SPECIAL, INDIRECT AND CONSEQUENTIAL
DAMAGES, EVEN IF SUN HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.

Use, duplication, or disclosure by the government is subject to
restrictions as set forth in subparagraph (c)(1)(ii) of the Rights in
Technical Data and Computer Software clause at DFARS 252.227-7013 and FAR
52.227-19.

Sun, Sun Microsystems and the Sun logo are trademarks or registered
trademarks of Sun Microsystems, Inc.

SunSoft, Inc.
2550 Garcia Avenue
Mountain View, California  94043

NOTE:

SunOS, SunSoft, Sun, Solaris, Sun Microsystems or the Sun logo are
trademarks or registered trademarks of Sun Microsystems, Inc.

*/

#ifndef _AST_INTERFACE_FWD_AST_INTERFACE_FWD_HH
#define _AST_INTERFACE_FWD_AST_INTERFACE_FWD_HH

#include "ast_type.h"
class AST_Interface;

// Representation of a forward interface declaration.

class TAO_IDL_FE_Export AST_InterfaceFwd : public virtual AST_Type
{
public:
  AST_InterfaceFwd (AST_Interface *dummy,
                    UTL_ScopedName *n);

  virtual ~AST_InterfaceFwd (void);

  AST_Interface *full_definition (void);

  /**
   * Sets the full definition. If there is an existing dummy definition, it
   * deletes that first. Ownership of the new definition is NOT assumed.
   */
  void set_full_definition (AST_Interface *nfd);

  virtual bool is_defined (void);
  void set_as_defined ();

  /**
   * Do not assume memory ownership of the full definition anymore.
   *
   * For example, this should be used if the dummy definition was made real and
   * added to a scope, which always assumes ownership of nodes.
   */
  void disown_full_definition ();

  virtual bool is_local (void);
  virtual bool is_valuetype (void);
  virtual bool is_abstract_valuetype (void);

  bool full_def_seen (void);

  // Cleanup function.
  virtual void destroy (void);

  // Narrowing.

  DEF_NARROW_FROM_DECL(AST_InterfaceFwd);

  // AST Dumping.
  virtual void dump (ACE_OSTREAM_TYPE &);

  // Visiting.
  virtual int ast_accept (ast_visitor *visitor);

  // Is this decl a forward declared type (Yes)
  virtual bool is_fwd (void);

  // We don't actually want the forward declaration,
  // but want to return the full definition member,
  // whether defined yet or not.
  virtual AST_Decl *adjust_found (bool ignore_fwd, bool full_def_only);

  static AST_Decl::NodeType const NT;

private:
  AST_Interface *pd_full_definition;
  // The interface this is a forward declaration of.

  bool is_defined_;
  // Checking the member above isn't good enough.

  /// True if we own pd_full_definition, which would be true if it's a dummy.
  bool has_ownership_;
};

#endif           // _AST_INTERFACE_FWD_AST_INTERFACE_FWD_HH

==> ace_7.0.0.orig.tar.gz: ACE_wrappers/TAO/TAO_IDL/include/ast_interface_fwd.h <==
// This may look like C, but it's really -*- C++ -*-
/*

COPYRIGHT

Copyright 1992, 1993, 1994 Sun Microsystems, Inc.  Printed in the United
States of America.  All Rights Reserved.

This product is protected by copyright and distributed under the following
license restricting its use.

The Interface Definition Language Compiler Front End (CFE) is made
available for your use provided that you include this license and copyright
notice on all media and documentation and the software program in which
this product is incorporated in whole or part. You may copy and extend
functionality (but may not remove functionality) of the Interface
Definition Language CFE without charge, but you are not authorized to
license or distribute it to anyone else except as part of a product or
program developed by you or with the express written consent of Sun
Microsystems, Inc. ("Sun").

The names of Sun Microsystems, Inc. and any of its subsidiaries or
affiliates may not be used in advertising or publicity pertaining to
distribution of Interface Definition Language CFE as permitted herein.

This license is effective until terminated by Sun for failure to comply
with this license.  Upon termination, you shall destroy or return all code
and documentation for the Interface Definition Language CFE.

INTERFACE DEFINITION LANGUAGE CFE IS PROVIDED AS IS WITH NO WARRANTIES OF
ANY KIND INCLUDING THE WARRANTIES OF DESIGN, MERCHANTIBILITY AND FITNESS
FOR A PARTICULAR PURPOSE, NONINFRINGEMENT, OR ARISING FROM A COURSE OF
DEALING, USAGE OR TRADE PRACTICE.

INTERFACE DEFINITION LANGUAGE CFE IS PROVIDED WITH NO SUPPORT AND WITHOUT
ANY OBLIGATION ON THE PART OF Sun OR ANY OF ITS SUBSIDIARIES OR AFFILIATES
TO ASSIST IN ITS USE, CORRECTION, MODIFICATION OR ENHANCEMENT.

SUN OR ANY OF ITS SUBSIDIARIES OR AFFILIATES SHALL HAVE NO LIABILITY WITH
RESPECT TO THE INFRINGEMENT OF COPYRIGHTS, TRADE SECRETS OR ANY PATENTS BY
INTERFACE DEFINITION LANGUAGE CFE OR ANY PART THEREOF.

IN NO EVENT WILL SUN OR ANY OF ITS SUBSIDIARIES OR AFFILIATES BE LIABLE FOR
ANY LOST REVENUE OR PROFITS OR OTHER SPECIAL, INDIRECT AND CONSEQUENTIAL
DAMAGES, EVEN IF SUN HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.

Use, duplication, or disclosure by the government is subject to
restrictions as set forth in subparagraph (c)(1)(ii) of the Rights in
Technical Data and Computer Software clause at DFARS 252.227-7013 and FAR
52.227-19.

Sun, Sun Microsystems and the Sun logo are trademarks or registered
trademarks of Sun Microsystems, Inc.

SunSoft, Inc.
2550 Garcia Avenue
Mountain View, California  94043

NOTE:

SunOS, SunSoft, Sun, Solaris, Sun Microsystems or the Sun logo are
trademarks or registered trademarks of Sun Microsystems, Inc.

*/

#ifndef _AST_INTERFACE_FWD_AST_INTERFACE_FWD_HH
#define _AST_INTERFACE_FWD_AST_INTERFACE_FWD_HH

#include "ast_type.h"
class AST_Interface;

// Representation of a forward interface declaration.

class TAO_IDL_FE_Export AST_InterfaceFwd : public virtual AST_Type
{
public:
  AST_InterfaceFwd (AST_Interface *dummy,
                    UTL_ScopedName *n);

  virtual ~AST_InterfaceFwd ();

  AST_Interface *full_definition ();

  /**
   * Sets the full definition. If there is an existing dummy definition, it
   * deletes that first. Ownership of the new definition is NOT assumed.
   */
  void set_full_definition (AST_Interface *nfd);

  virtual bool is_defined ();
  void set_as_defined ();

  /**
   * Do not assume memory ownership of the full definition anymore.
   *
   * For example, this should be used if the dummy definition was made real and
   * added to a scope, which always assumes ownership of nodes.
   */
  void disown_full_definition ();

  virtual bool is_local ();
  virtual bool is_valuetype ();
  virtual bool is_abstract_valuetype ();

  bool full_def_seen ();

  // Cleanup function.
  virtual void destroy ();

  // AST Dumping.
  virtual void dump (ACE_OSTREAM_TYPE &);

  // Visiting.
  virtual int ast_accept (ast_visitor *visitor);

  // Is this decl a forward declared type (Yes)
  virtual bool is_fwd ();

  // We don't actually want the forward declaration,
  // but want to return the full definition member,
  // whether defined yet or not.
  virtual AST_Decl *adjust_found (bool ignore_fwd, bool full_def_only);

  static AST_Decl::NodeType const NT;

private:
  AST_Interface *pd_full_definition;
  // The interface this is a forward declaration of.

  bool is_defined_;
  // Checking the member above isn't good enough.

  /// True if we own pd_full_definition, which would be true if it's a dummy.
  bool has_ownership_;
};

#endif           // _AST_INTERFACE_FWD_AST_INTERFACE_FWD_HH
